#
# spec file for package libdrm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libdrm
Url:            http://dri.freedesktop.org/
Version:        2.4.65
Release:        1.5
Provides:       libdrm23 = %{version}
Obsoletes:      libdrm23 < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libdrm-64bit < %{version}
Provides:       libdrm-64bit = %{version}
%endif
#
Summary:        Userspace Interface for Kernel DRM Services
License:        MIT
Group:          System/Libraries

#Git-Clone:	git://anongit.freedesktop.org/git/mesa/drm
#Git-Web:	http://cgit.freedesktop.org/mesa/drm/
# Source URL:   http://dri.freedesktop.org/libdrm/
Source:         http://dri.freedesktop.org/libdrm/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM libdrm-implicit-defs.diff fdo#48599 -- Fix compiler warnings in tests/radeon/radeon_ttm.c
Patch2:         u_Fix-compilation-on-systems-that-don-t-provide-O_CLOE.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.10
BuildRequires:  libtool >= 2.2
BuildRequires:  pkgconfig
%if 0%{suse_version} >= 1320
BuildRequires:  util-macros-devel
%endif
BuildRequires:  pkgconfig(pciaccess) >= 0.10
BuildRequires:  pkgconfig(pthread-stubs)
%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390x %arm
BuildRequires:  pkgconfig(valgrind)
%endif

%description
The package contains the userspace interface to the kernel DRM
services.

%package tools
Summary:        Diagnostic utilities for DRI and DRM
Group:          System/Base
# O/P added in 12.2
Obsoletes:      libdrm < %version-%release
Provides:       libdrm = %version-%release

%description tools
(Upstream has not provided a description)

%package devel
Summary:        Libraries, includes and more to develop libdrm applications
Group:          Development/Libraries/X11
Requires:       libdrm2 = %version
Requires:       libdrm_amdgpu1 = %version
Requires:       libdrm_nouveau2 = %version
Requires:       libdrm_radeon1 = %version
%ifarch %arm aarch64
Requires:       libdrm_freedreno1 = %version
%endif
%ifarch %arm
Requires:       libdrm_omap1 = %version
Requires:       libdrm_tegra0 = %version
%endif
%ifarch %ix86 x86_64
Requires:       libdrm_intel1 = %version
%endif
# bug437293
%ifarch ppc64
Obsoletes:      libdrm-devel-64bit < %{version}
Provides:       libdrm-devel-64bit = %{version}
%endif

%description devel
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems that support the ioctl
interface, and for chipsets with DRM memory manager, support for
tracking relocations and buffers. libdrm is a low-level library,
typically used by graphics drivers such as the Mesa DRI and X
drivers.

This package contains the development headers for the library found
in libdrm2.

%package -n libdrm2
Summary:        Userspace Interface for Kernel DRM Services
Group:          System/Libraries

%description -n libdrm2
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems that support the ioctl
interface, and for chipsets with DRM memory manager, support for
tracking relocations and buffers. libdrm is a low-level library,
typically used by graphics drivers such as the Mesa DRI and X
drivers.

%package -n libdrm_intel1
Summary:        Userspace interface for Kernel DRM services for Intel chips
Group:          System/Libraries

%description -n libdrm_intel1
(Upstream has not provided a description)

%package -n libdrm_nouveau2
Summary:        Userspace interface for Kernel DRM services for NVIDIA chips
Group:          System/Libraries

%description -n libdrm_nouveau2
(Upstream has not provided a description)

%package -n libdrm_radeon1
Summary:        Userspace interface for Kernel DRM services for AMD Radeon chips
Group:          System/Libraries

%description -n libdrm_radeon1
(Upstream has not provided a description)

%package -n libdrm_amdgpu1
Summary:        Userspace interface for Kernel DRM services for AMD Radeon chips
Group:          System/Libraries

%description -n libdrm_amdgpu1
(Upstream has not provided a description)

%package -n libkms-devel
Summary:        Development files for the KMS MM abstraction library
Group:          Development/Libraries/C and C++
Requires:       libkms1 = %version

%description -n libkms-devel
This package contains the development headers for the library found
in libkms1.

%package -n libkms1
Summary:        Userspace interface to kernel DRM buffer management
Group:          System/Libraries

%description -n libkms1
The KMS Memory Management abstraction library.

%package -n libdrm_omap1
Summary:        Userspace interface to kernel DRM services for omap chips
Group:          System/Libraries

%description -n libdrm_omap1
(Upstream has not provided a description)

%package -n libdrm_freedreno1
Summary:        Userspace interface to kernel DRM services for Qualcomm Adreno chips
Group:          System/Libraries

%description -n libdrm_freedreno1
(Upstream has not provided a description)

%package -n libdrm_tegra0
Summary:        Userspace interface to kernel DRM services for Nvidia Tegra chips
Group:          System/Libraries

%description -n libdrm_tegra0
(Upstream has not provided a description)

%prep
%setup -q
# reverse apply (fdo#89842)
%patch2 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
autoreconf -fi
%configure --with-pic \
%ifnarch %ix86 x86_64 ppc ppc64 ppc64le s390x %arm
	   --disable-valgrind \
%endif
%ifarch %arm
	   --enable-omap-experimental-api \
	   --enable-freedreno-experimental-api \
           --enable-tegra-experimental-api \
%endif
	   --enable-udev

make %{?_smp_mflags}
make %{?_smp_mflags} -C tests dristat drmstat

%check
make %{?_smp_mflags} -C tests check-am

%install
make install DESTDIR=$RPM_BUILD_ROOT
make -C tests/modeprint install DESTDIR=$RPM_BUILD_ROOT
make -C tests/modetest install DESTDIR=$RPM_BUILD_ROOT
rm -f "%buildroot/%_libdir"/*.la
%{__mkdir} -p $RPM_BUILD_ROOT/usr/bin
%{__install}  \
    tests/dristat \
    tests/.libs/drmstat \
    tests/modeprint/.libs/modeprint \
    tests/modetest/.libs/modetest $RPM_BUILD_ROOT/usr/bin

%post   -n libdrm2 -p /sbin/ldconfig

%postun -n libdrm2 -p /sbin/ldconfig

%post   -n libdrm_intel1 -p /sbin/ldconfig

%postun -n libdrm_intel1 -p /sbin/ldconfig

%post   -n libdrm_nouveau2 -p /sbin/ldconfig

%postun -n libdrm_nouveau2 -p /sbin/ldconfig

%post   -n libdrm_radeon1 -p /sbin/ldconfig

%postun -n libdrm_radeon1 -p /sbin/ldconfig

%post   -n libdrm_amdgpu1 -p /sbin/ldconfig

%postun -n libdrm_amdgpu1 -p /sbin/ldconfig

%post   -n libkms1 -p /sbin/ldconfig

%postun -n libkms1 -p /sbin/ldconfig

%ifarch %arm
%post   -n libdrm_omap1 -p /sbin/ldconfig

%postun -n libdrm_omap1 -p /sbin/ldconfig

%post   -n libdrm_tegra0 -p /sbin/ldconfig

%postun -n libdrm_tegra0 -p /sbin/ldconfig
%endif

%ifarch %arm aarch64
%post   -n libdrm_freedreno1 -p /sbin/ldconfig

%postun -n libdrm_freedreno1 -p /sbin/ldconfig
%endif

%files tools
%defattr(-,root,root)
%_bindir/dristat
%_bindir/drmstat
%_bindir/modeprint
%_bindir/modetest

%files devel
%defattr(-,root,root)
%_includedir/libdrm
%ifarch %arm
%_includedir/omap
%endif
%ifarch %arm aarch64
%_includedir/freedreno
%endif
%_includedir/xf86drm.h
%_includedir/xf86drmMode.h
%_libdir/libdrm*.so
%_libdir/pkgconfig/libdrm*.pc

%files -n libdrm2
%defattr(-,root,root)
%_libdir/libdrm.so.2*

%ifarch %ix86 x86_64

%files -n libdrm_intel1
%defattr(-,root,root)
%_libdir/libdrm_intel.so.1*
%endif

%files -n libdrm_nouveau2
%defattr(-,root,root)
%_libdir/libdrm_nouveau.so.2*

%files -n libdrm_radeon1
%defattr(-,root,root)
%_libdir/libdrm_radeon.so.1*

%files -n libdrm_amdgpu1
%defattr(-,root,root)
%_libdir/libdrm_amdgpu.so.1*

%files -n libkms1
%defattr(-,root,root)
%_libdir/libkms.so.1*

%files -n libkms-devel
%defattr(-,root,root)
%_includedir/libkms
%_libdir/libkms.so
%_libdir/pkgconfig/libkms.pc

%ifarch %arm
%files -n libdrm_omap1
%defattr(-,root,root)
%_libdir/libdrm_omap.so.1*

%files -n libdrm_tegra0
%defattr(-,root,root)
%_libdir/libdrm_tegra.so.0*
%endif

%ifarch %arm aarch64
%files -n libdrm_freedreno1
%defattr(-,root,root)
%_libdir/libdrm_freedreno.so.1*
%endif

%changelog
* Mon Sep 21 2015 sndirsch@suse.com
- Update to version 2.4.65
  * bugfixes
* Wed Aug 19 2015 tobias.johannes.klausmann@mni.thm.de
- Add libdrm_amdgpu1 as a requirement for libdrm-devel
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 2.4.64:
  + amdgpu:
  - Improve amdgpu_vamgr_init.
  - Add flag to support 32bit VA address v4.
  - Make vamgr per device v2.
  + tests/amdgpu:
  - Include config.h first.
  - Remove unused local variable 'i'.
  + freedreno/msm:
  - Reorg ringbuffer struct.
  - Fix issue where same bo is on multiple rings.
  - Dump out submit info on error.
  + freedreno:
  - Add fd_pipe_wait_timeout().
  - Update freedreno-symbol-check.
  + tests: modetest: Accept connector names in addition to
    connector IDs.
  + libdrm:
  - Remove gratuitous blank lines.
  - Make indentation consistent.
- Use url to tarball as source.
* Fri Aug 14 2015 mimi.vx@gmail.com
- update baselibs.conf for AMDGPU
* Fri Aug 14 2015 mimi.vx@gmail.com
- update to version 2.4.6.3
  * This release adds AMDGPU driver, adds new AMD OLAND PCIids
* Mon Jul 27 2015 schwab@suse.de
- Disable valgrind support if not available
* Tue Jun 30 2015 sndirsch@suse.com
- Update to version 2.4.62
  * This release introduces the atomic and blob APIs, adds support
    for new devices (AMD Bonaire) and a new flag for coherent BOs
    in nouveau.
* Fri May  8 2015 sndirsch@suse.com
- Update to version 2.4.61
  * Release to fix regression in nouveau in 2.4.60, but brings lots
    of android changes and other fixes.
- deprecates reverse applied patches
  * U_nouveau-Do-not-add-most-bo-s-to-the-global-bo-list.patch
  * U_nouveau-make-nouveau-importing-global-buffers-comple.patch
* Wed Apr 29 2015 sndirsch@suse.com
- U_nouveau-Do-not-add-most-bo-s-to-the-global-bo-list.patch
  U_nouveau-make-nouveau-importing-global-buffers-comple.patch
  * reverse apply these patches in order to fix a regression in
    2.4.60 triggered by new legacy tray in GNOME 3.16.0 (fdo#89842)
* Wed Apr  8 2015 schwab@suse.de
- Build package libdrm_freedreno1 also on aarch64
* Fri Mar 20 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.60:
  + bugfixes and cleanup
  + exynos improvements
* Sun Feb 22 2015 zombah@gmail.com
- Fix include directories
* Thu Feb 19 2015 zombah@gmail.com
- Add subpackage libdrm_tegra0 for Nvidia Tegra chips
* Mon Feb  9 2015 sndirsch@suse.com
- Update to version 2.4.59:
  * bugfixes
  * more Intel Skylake support
* Sun Sep 28 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.58:
  Build fixes for 32bit Systems.
* Sun Sep 28 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.57:
  + Intel Userptr support.
  + Android build support.
  + New "SI" and "CIK" PCI IDs for the libdrm Radeon graphics
    driver code.
  + DMA-BUF import/export helpers were added to libdrm's Freedreno
    driver support.
* Tue Jul 29 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.56:
  Libdrm 2.4.56 has been released. It fixes MSAA for the Radeon Hawaii GPU.
- Remove upstreamed patch:
  u_No-longer-hardcode-path-for-drm.h-include-in-qxl_drm.patch
* Fri Jul 25 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.55:
  + exynos: do not build fimg2d_test when building without libkms support.
  + radeon: Add missing header includes.
  + exynos: fix scaling factor computation in g2d_copy_with_scale
  + exynos: fix G2D_DOUBLE_TO_FIXED for non-integer input
  + exynos: fix coordinate computation in g2d_copy
  + intel: Add new userptr ioctl
  + intel: Sync typo fix from the kernel sources.
  + intel: Sync the command parser version parameter from kernel
  + freedreno: add chip-id property
  + freedreno: sync kernel header
  + drm: Add universal plane capability bit and plane type enums
  + exynos: prime: use drmPrime*() helpers
  + exynos_fimg2d_test: fix drmModeRmFB
  + eyxnos: install exynos tests if HAVE_INSTALL_TESTS
- Drop upstreamed patches:
  + libdrm-implicit-defs.diff (Patch1)
* Sun May 25 2014 afaerber@suse.de
- Enable valgrind support for armv6l and ppc64le
* Sun May  4 2014 tobias.johannes.klausmann@mni.thm.de
- Fix typos in package description
* Fri May  2 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.54:
  + Use signed location for drmModeSetPlane
  + nouveau: safen up nouveau_device list usage against concurrent access
  + amend previous commit to actually compile
  + modetest: add cursor support
  + freedreno: add missing fxn prototype
  + radeon: add Mullins chip family
  + radeon: add Mullins pci ids
  + Mark functions printf-like where possible
  + intel: Fix some format strings
  + libdrm: Remove extraneous parameter
  + tests: Use drmFreeVersion() instead of drmFree()
  + intel/chv: Add Cherryview PCI IDs
* Thu Apr 24 2014 sndirsch@suse.com
- u_No-longer-hardcode-path-for-drm.h-include-in-qxl_drm.patch:
  * No longer hardcode path for drm.h include in qxl_drm.h, i.e.
    handle it the same as in other <driver>_drm.h files; change
    required for KMS support in xf86-video-qxl (bnc#870501)
* Sat Apr 12 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.53:
  + drm: Implement drmCheckModesettingSupported() for FreeBSD
  + Enable libkms by default on DragonFly
  + freedreno: do not leak drmVersion
  + freedreno: fix license
  + freedreno: some msm-ring reset/flush fixes
  + freedreno: simplify device creation
  + freedreno: fix null ptr in error path
  + freedreno/kgsl: don't even bother trying CREATE_FD
  + freedreno: zero out unused field
  + modeprint: pretty print connector names
  + radeon: sync with radeon_drm.h from kernel headers
- Remove upstream patch: Patch3: U_freedreno_license_fix.patch
* Sun Feb 16 2014 afaerber@suse.de
- U_freedreno_license_fix.patch: Backport relicensing of freedreno
  DRM header from GPL-2.0 to MIT (bnc#860595).
* Tue Jan 21 2014 sndirsch@suse.com
- Update to version 2.4.52
  + intel: squash unused variable 'bo_gem'
  + intel: Handle malloc fails in context create
  + intel: Merge latest i915_drm.h
  + drm: Initialize or valgrind-clear modesetting ioctl arguments.
  + intel: Track whether a buffer is idle to avoid trips to the kernel.
  + tests/kmstest: support exynos
  + Mark debug_print with __attribute__ ((format(__printf__, 1, 0)))
  + intel: Create a new drm_intel_bo offset64 field.
  + freedreno: add fd_device_new_dup()
  + modetest: add the possibility to select the refresh frequency for a mode
* Wed Jan 15 2014 afaerber@suse.de
- Make libdrm-devel depend on libdrm_freedreno1 on arm
* Wed Jan 15 2014 afaerber@suse.de
- Add subpackage for freedreno (Qualcomm Adreno)
* Wed Jan  8 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.51:
  + radeon: avoid possible divide by 0 in surface manager
  + radeon: fix sumo2 pci id
  + intel/test_decode: Allow gen8 to be infered from the batch filenames
  + freedreno: add bo cache
  + freedreno/kgsl: fix crash introduced w/ bo-cache
  + freedreno: allow IB to different ringbuffer
* Wed Dec  4 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.50:
  + intel: Track known prime buffers for re-use
  + radeon: Update unaligned offset for 2D->1D tiling transition on SI
- Droped U_update-unaligned-offset-for-2D-1D-tiling-transition-on-SI.patch,
  included in this release
* Mon Nov 25 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.49:
  + intel: Use memset instead of VG_CLEAR
  + radeon: implement 2D tiling for CIK
  + radeon: handle P16 pipe configs for Hawaii
  + radeon: fix mipmap level 0 and 1 alignment for SI and CIK
  + radeon: don't overallocate stencil by 4 on SI and CIK
  + libdrm/mode: Update the encoder and connector defines
- Added U_update-unaligned-offset-for-2D-1D-tiling-transition-on-SI.patch:
  fdo#71983, resolves crasing on radeon SI chips wth 2.4.49
* Sat Nov 16 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.48:
  + radeon: add hawaii chip family
  + radeon: add hawaii pci ids
  + intel/bdw: Add broadwell chipset IDs
  + intel/bdw: Handle gen8 bufmgr_init
  + intel/bdw: Add gen8 to the decode init
  + intel/bdw: Update MI_BATCH_BUFFER_START for aub dumps
  + Revert "intel: Add support for GPU reset status query ioctl"
  + intel: Add support for GPU reset status query ioctl
  + intel: Add support for GPU reset status query ioctl
  + libdrm: bump to 2.4.48
  + Add DRM_MODE_PAGE_FLIP_ASYNC define
  + intel: Add the Gen6+ version of MI_REPORT_PERF_COUNT to
    intel_decode.c.
  + intel: Add MI_LOAD_REGISTER_MEM to intel_decode.c.
  + intel/bdw/aub: Update AUB trace block writes for 48-bit
    addressing.
  + nouveau: prevent undefined behavior in nouveau_pushbuf_reloc
    with gcc-4.8
* Sun Oct 27 2013 sndirsch@suse.com
- updated to re-uploaded 2.4.47 tarball with correct checksums
* Fri Oct 11 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.47:
  + libdrm: add missing DRM_CAP_TIMESTAMP_MONOTONIC
  + modetest fixes
  + radeon: add berlin pci ids
  + intel: Update package name and description in libdrm_intel.pc
  + freedreno fixes
  + radeon: Fix tiling mode index for 1D tiled depth/stencil
    surfaces on CIK
  + radeon: fix pitch alignment for non-power-of-two mipmaps on SI
  + drm: Synchronize the stereo 3D mode flags from the kernel headers
  + drm: Sync the DRM_SET_CLIENT_CAP ioctl definition
  + drm: Introduce a drmSetClientCap() wrapper
  + intel: Set bo size from lseek if kernel supports it
- Droped U_radeon-pad-CS-to-8-DW.patch, included in this release
* Tue Sep 17 2013 hrvoje.senjan@gmail.com
- Added U_radeon-pad-CS-to-8-DW.patch from upstream -- aligns the
  IB to 8 DWs. r6xx also require at least 4 DW alignment to avoid
  a hw bug.
* Thu Aug 29 2013 ro@suse.de
- buildrequire valgrind on the arch list that valgrind builds on
* Tue Jul  2 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.46:
  + radeon: add CIK chip families
  + radeon: add Bonaire pci ids
  + radeon: add kabini pci ids
  + intel/aub: Sync the AUB defines with mesa's
  + intel/aub: Return early if we disable aub dumps
  + intel/aub: Implement a way to specify the output .aub filename
  + drm: add hotspot cursor interface support.
  + radeon: correct RADEON_GEM_WAIT_IDLE use
  + freedreno: add handle and name tracking
  + freedreno: add some asserts
  + freedreno: also remove from name table on bo delete
  + intel: Fix Haswell GT3 names.
  + intel: Adding more reserved PCI IDs for Haswell.
  + modetest: Make RGB565 pwetty too
* Tue May 21 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.45:
  The main motivation for this
  release is the changes in the radeon surface allocator, which helps fix
  multisample textures on the Radeon Cayman family chipsets.
  + radeon: add new SI pci ids
  + radeon: add new richland pci ids
  + radeon: add HAINAN family
  + radeon: add HAINAN pci ids
  + drm: add qxl drm header file
  + radeon: add RADEON_SURF_FMASK flag which disables 2D->1D tiling transition
  + freedreno: add gpu-id property
  + Add exynos_fimg2d_test to .gitignore
  + freedreno: add synchronization between mesa and ddx
  + intel: Add support for VEBOX ring (v2)
* Fri Apr 19 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.44:
  New release for radeonsi tiling support
  + drm: Fix error message in drmWaitVBlank
  + intel-decode: Fix gen6 HIER_DEPTH_BUFFER decoding
  + radeon: update radeon_drm.h to kernel last API additions v2
  + radeon: add si tiling support v5
  + intel: Fix Haswell CRW PCI IDs.
  + kms: Make libkms.h usable in C++
  + kms: Return a negative error code in kms_bo_create()
  + Remove unused header xf86mm.h.
  + makefiles: Add missing headers.
  + freedreno: add shifted reloc
  + modetest: Fix pitches, somewhat
  + modetest: Add support for all 16/32 bpp RGB formats
  + modetest: Print possible_crtcs for planes
  + modetest: Reduce the length of the connector type string
  + modetest: Pass format_info to fill_tiles functions
  + modetest: Add YUV420 support and fix YVU420 Cb/Cr ordering
* Wed Mar 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.43:
  + radeon: add pci ids for Richland APUs
  + intel_chipset: Merge intel-gpu-tools chipsets
  + tests: allow tests programs to be installed
  + tests: allow tests programs to be installed (cumulative patch)
  + intel: fix length mask for Gen5/Gen6 3DSTATE_CLEAR_PARAMS
  + libdrm/exynos: add test application for 2d gpu.
  + radeonsi: make sure tile_split field are not garbage
  + intel/aub: Actually run BLT batches on the blit ring.
  + nouveau: return error from pushbuf_validate
  + nouveau: add a way to override single pushbuffer memory limits
  + freedreno: add freedreno DRM
  + intel_chipset: Use parens around macro arguments
  + intel_chipset: Fix up VLV confusion
* Mon Mar 25 2013 jengelh@inai.de
- Remove unneeded dependency on libkms-devel
* Wed Feb 27 2013 dmueller@suse.com
- disable valgrind support for aarch64
* Tue Feb  5 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.42:
  + radeon: add OLAND family
  + radeon: add OLAND pci ids
  + man: fix manpage build instructions
  + intel: add more VLV PCI IDs
  + nouveau: use @PACKAGE_VERSION@ in libdrm_nouveau.pc
  + libdrm: remove DISTCHECK_CONFIGURE_FLAGS
  + configure.ac: bump version to 2.4.42 for release
  + radeon: Fix 1D tiling layout on SI.
  + man: Fix typo and use $() for make expressions
* Wed Jan 16 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.41:
  + radeon: add new SI pci id
  + nouveau: disallow pushbuf BOs in multiple memory types
  + nouveau: expose channel engine selection on kepler chipsets
  + intel: Remove the fence count contributions when clearing relocs
  + man: convert manpages to XML instead of plain troff
  + man: add drm.7 overview page
  + man: add drm-kms overview page
  + man: add drm-memory overview page
  + intel: Fix missing ETIME on BSD operating systems
  + drm/radeon: track global bo name and always return the same
  + man: disable man page building until David saves us all
  + libdrm_nouveau.pc: don't include I${includedir}/nouveau
  + libkms: fix memory leak in error path
  + libkms: return -EINVAL on fstat error
* Tue Nov  6 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.40:
  + radeon: add some new SI pci ids
  + radeon: fix unused-function warning
  + intel: Fix "properly test for HAS_LLC"
  + intel: Correct the word decoding for gen2 3DSTATE_LOAD_STATE_IMMEDIATE_1
  + configure.ac: Allow forcible disabling of Cairo support
  + intel: properly test for HAS_LLC
  + fix make distcheck
  + vmwgfx: No longer experimental
  + intel: add support for ValleyView
  + libdrm: man page infrastructure and a few sample man pages
  + intel: Mark bo's exported to prime as not reusable
  + libkms: link against libdrm
  + radeon: don't take the stencil-specific codepath for buffers without
    stencil
  + radeon: don't force stencil tile split to 0
  + radeon: fix stencil miptree allocation of combined ZS buffers on EG and
    SI
  + radeon: fix tile_split of 128-bit surface formats with 8x MSAA
  + radeon: Fix layout of linear aligned mipmaps on SI.
  + radeon: Memory footprint of SI mipmap base level is padded to powers of
    two.
  + radeon: Sampling pitch for non-mipmaps seems padded to slice alignment
    on SI.
  + initialize width/height fields in drmModeCrtc
  + omap: release lock also on error paths
* Thu Sep 27 2012 idonmez@suse.com
- Require libdrm_omap1-32bit only on ARM
* Sun Sep 23 2012 sndirsch@suse.com
- u_Fix-compilation-on-systems-that-don-t-provide-O_CLOE.patch
  * Fix compilation on systems that don't provide O_CLOEXEC.
    Patch suggestion by Thomas Klausner <wiz%%NetBSD.org@localhost>.
    See also http://mail-index.netbsd.org/pkgsrc-changes/2012/08/13/msg076887.html
* Thu Sep 20 2012 sndirsch@suse.com
- let libdrm-devel require libkms-devel
* Fri Aug 24 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.39:
  + radeon: add prime import/export support
  + intel: Use VG_CLEAR on the context destroy ioctl as well.
  + radeon: fix allocation of MSAA surfaces on r600-r700
  + radeon: align r600 msaa buffers to a multiple of macrotile size
  * num samples
  + tests/modetest: Add a forgotten return, needed for opensuse buildservice
  + omap: include omap_drm.h independently
* Mon Aug 13 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.38:
  + Bugfix release
* Sun Jul 22 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.37:
  + Put the proper context APIs in place.
- Add a patch to build 2.4.37 successfully!
  + Added N_0001-Add-a-forgotten-return-needed-for-opensuse-buildserv.patch
* Thu Jul  5 2012 sndirsch@suse.com
- build omap support only on %%arm platform
* Tue Jul  3 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.36:
  + packaging changes:
  - nouveau.h was moved out from its subdirectory (upstream change)
  - lidrm_nouveau version bumped to 2
  - Removed --enable-nouveau-experimental-api from configure
    it is now stable and will build without it
  + new in this release:
  - Context API and wait render timeout API added to libdrm for Intel
* Mon Jul  2 2012 guillaume@opensuse.org
- Disable valgrind support for armv5 since valgrind only supports armv7
* Fri Jun 29 2012 sndirsch@suse.com
- U_intel-add-Ivy-Bridge-GT2-server-variant.patch
  * intel: add Ivy Bridge GT2 server variant (bnc#769209)
* Wed Jun 27 2012 guillaume@opensuse.org
- enable omapdrm support
* Tue May 29 2012 sndirsch@suse.com
- back to libdrm 2.4.33, since 2.4.34 currentlz requires Mesa git
  master changes for nouveau Mesa driver build
* Sat May 26 2012 crrodriguez@opensuse.org
- update to version 2.4.34, see NEWS for detail, here follows
  packaging changes only.
  + nouveau.h was moved out from its subdirectory (upstream change)
  + lidrm_nouveau version bumped to 2.
  + remove obsolete configure options.
  + Fix many more "implicit declarations" and "undefined references"
* Thu Apr 12 2012 vuntz@opensuse.org
- Update to version 2.4.33:
  + intel: add some PCI IDs for Haswell
  + omap: add omapdrm support
  + radeon: add TN surface support
- Changes from version 2.4.32:
  + Add valgrind support
  + Make drm/drm_fourcc.h portable to non-linux platforms
  + intel:
  - Add support for (possibly) unsynchronized maps
  - Add .aub file output support
  - Add support for overriding the PCI ID via an environment
    variable
  - Add decode for gen7 3DSTATE_WM, HIER_DEPTH_BUFFER
  - Add per-dword decode of gen7 3DPRIMITIVE
  + radeon: fix pitch alignment for scanout buffer
  + radeon_cs_setup_bo: Fix accounting if caller specified write
    and read domains
  + Build system improvements
- Add pkgconfig(valgrind) BuildRequires to build valgrind support.
* Sun Feb 26 2012 dmueller@suse.de
- fix build on arm
* Wed Feb 22 2012 dvaleev@suse.com
- don't package libdrm-intel on ppc, ppc64. As there is not intel
  cards
* Sat Feb 11 2012 jengelh@medozas.de
- Update to new upstream release 2.4.31
  * radeon: add surface allocator helper v10
  * intel: add sprite ioctl defines and struct for i915 sprite code
- Remove autoreconf call for now, there are no patches that
  would necessitate this
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Package shlibs separately according to policy
- Package description updates
* Mon Jan 16 2012 vljn@ovi.com
- Update to libdrm-2.4.30
  * required for lastest Mesa
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Wed Nov  2 2011 sndirsch@suse.com
- Update to libdrm 2.4.27
  * required for latest intel driver ...
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: move testing to %%check section
* Fri Jun 17 2011 vljn@ovi.com
- Update to libdrm 2.6.26
- obsoletes intel-Export-CONSTANT_BUFFER-addressing-mode.patch
- a bunch of fixes
- new Intel API for use by mesa
* Wed May 25 2011 sndirsch@novell.com
- install the binaries of dristat, drmstat, drmmodeprint and
  drmmodetest instead of the useless libtool wrappers ...
* Tue May 24 2011 eich@suse.de
- removed patch: enable_test_tools.diff.
  - Building and installing dristat and drmstat can be done
    from the spec file. Same is true for installing drmmodeprint
    and drmmodetest.
* Wed Jan  5 2011 sndirsch@novell.com
- intel-Export-CONSTANT_BUFFER-addressing-mode.patch
  * intel: Export CONSTANT_BUFFER addressing mode
* Mon Dec 20 2010 sndirsch@novell.com
- removed revert-09b1062.diff; due to Mesa 7.10-pre update no longer
  required/useful
* Sat Dec 11 2010 sndirsch@novell.com
- libdrm 2.4.23
  * drm: don't do the create the node ourselves if we have udev.
  * intel: Reorder need_fence vs fenced_command to avoid fences on
    gen4
  * tests: Update for ENOENT returns from unknown handles
* Sat Dec  4 2010 sndirsch@novell.com
- updated to git master commit #af3d282 (2010-12-03, still 2.4.22)
- obsoletes intel-initialize-bufmgr.bo_mrb_exec-unconditionally.patch
* Mon Nov  8 2010 sndirsch@novell.com
- intel-initialize-bufmgr.bo_mrb_exec-unconditionally.patch
  * no longer require kernels without BLT ring support (2.6.34 an
    before). (bnc #651989, bnc #651501)
* Sat Nov  6 2010 sndirsch@novell.com
- updated to git master commit #a52e61b (2010-11-02, still 2.4.22)
* Tue Nov  2 2010 sndirsch@novell.com
- updated to git master commit #d0a4f2e (2010-10-31, still 2.4.22)
- revert-09b1062.diff (to fix Mesa's nouveau driver build)
  * Revert "nouveau: Let the user choose the push buffer size."
    This reverts commit 09b1062628f2cbddb3ebae20e7b3b8a0a93acebf.
* Wed Sep 29 2010 sndirsch@novell.com
- libdrm 2.4.22
  * nouveau: fix thinko in drm version check
  * nouveau: fix drm version check some more
  * intel: Replace open-coded drmIoctl with calls to drmIoctl()
* Wed Sep 15 2010 sndirsch@novell.com
- updated to git master commit #7ec9a1e (2010-09-09, still 2.4.21)
* Sat Aug 28 2010 sndirsch@novell.com
- updated to git master commit #23287f0 (still 2.4.21)
- "--enable-nouveau-experimental-api" configure option appears to
  be obsolete meanwhile
- enabled build of VMWare's experimental API
* Tue Jul  6 2010 johannesobermayr@gmx.de
- bnc #620037
  * remove libdrm-204c76c.diff (reverse applied)
- silence some RPMLINT warnings
* Thu Jun 24 2010 sndirsch@suse.de
- updated to git master commit #726210f
  * various tiling related fixes for intel
* Tue Jun 15 2010 sndirsch@suse.de
- libdrm 2.4.21
- obsoletes commit-3506173.diff
- adjusted enable_test_tools.diff
- libdrm-204c76c.diff (reverse applied)
  * old nouveau gallium driver in Mesa still requires
    nouveau_class.h in libdrm
* Mon May 31 2010 sndirsch@suse.de
- intel: Use the correct size when allocating reloc_target_info
  array. Thomas tracked down this error with kdm and commit b509640
  (bnc #608149)
* Fri Apr  9 2010 sndirsch@suse.de
- libdrm 2.4.20
  * /usr/include/drm/ --> /usr/include/libdrm/
  * /usr/include/intel_bufmgr.h --> /usr/include/libdrm
* Thu Mar 18 2010 coolo@novell.com
- fix typo in description
* Wed Mar 17 2010 ro@suse.de
- update to 2.4.19 for Mesa-7.8
  * added nouveau driver
  * added kms wrapper library driver
* Sun Feb 28 2010 sndirsch@suse.de
- update to libdrm 2.4.18, which also obsoletes
  * intel-Account-for-potential-pinned-buffers-hogging-f.patch
  * intel-Handle-resetting-of-input-params-after-EINTR-d.patch
* Wed Feb 17 2010 sndirsch@suse.de
- intel-Account-for-potential-pinned-buffers-hogging-f.patch
  * intel: Account for potential pinned buffers hogging fences
    (bfo #25911)
- intel-Handle-resetting-of-input-params-after-EINTR-d.patch
  * intel: Handle resetting of input params after EINTR during
    SET_TILING (bfo #25475, bfo #25554)
* Wed Jan  6 2010 sndirsch@suse.de
- update to libdrm 2.4.17, which is part of Intel 2009Q4 release
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Dec  4 2009 sndirsch@suse.de
- update to libdrm 2.4.16
  * "Here's the 2.4.16 release of libdrm.  There are a lot of
    changes this time, in particular we dropped the orphaned
    driver code from Linux and BSD and this release is now
    really just libdrm.  Going forward, the drm header files
    we ship in libdrm will be a straight copy from the linux
    kernel header files.  Once a feature is merged into the
    drm-next branch of Dave's kernel tree the header files can
    be copied from $kernel_src/usr/include/drm into libdrm and
    userspace support for the new functionality can be added."
* Fri Dec  4 2009 sndirsch@suse.de
- readded modeprint, modetest for intel driver
* Tue Dec  1 2009 sndirsch@suse.de
- libdrm 2.4.15_2009-12-01_8ffd2e1
  * update to git commit 8ffd2e1 (2009-12-01); required for
    xf86-video-intel 2.10 RC1
- adjusted enable_test_tools.diff
* Wed Nov  4 2009 ro@suse.de
- add "--enable-radeon-experimental-api --enable-udev"
  to configure arguments and package libdrm_radeon as well
* Thu Oct 29 2009 sndirsch@suse.de
- enable_test_tools.diff
  * enabled build of test tools (dristat, drmstat, modeprint,
    modeset)
* Wed Oct 28 2009 crrodriguez@opensuse.org
- libdrm-devel requires glibc-devel.
* Tue Sep 29 2009 sndirsch@suse.de
- libdrm 2.4.14
  * intel: adds support for G41, B43 and Ironlake
* Sat May 16 2009 sndirsch@suse.de
- libdrm 2.4.11
  * Two releases in one, so twice the usual tiny amount of changes.
    Both of the new libdrm_intel interfaces enable KMS fixes in the
    Intel 2D driver.
- enabled build of Nouveau's experimental API
* Sat Apr 18 2009 sndirsch@suse.de
- libdrm 2.4.9
  * Aka, the "kick jbarnes" release.  Not only did I push the
    broken speedup patch but I flubbed the version bump, so we get
    to go from 2.4.7 to 2.4.9.  Yay for me.
* Fri Apr 10 2009 sndirsch@suse.de
- libdrm 2.4.7
  * quick follow on release to 2.4.6 to fix an embarrasing
    build problem in the test suite when libudev is not available.
- obsoletes libdrm-commit-1faab66.diff
* Tue Apr  7 2009 sndirsch@suse.de
- libdrm 2.4.6
  * various fixes
- libdrm-commit-1faab66.diff
  * fixes build of 2.4.6
* Wed Feb 25 2009 sndirsch@suse.de
- libdrm 2.4.5
* Fri Jan 23 2009 sndirsch@suse.de
- Provides/Obsolete: libdrm23, i.e. get rid of confusing SLE10
  packages (bnc #468796)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Oct 31 2008 sndirsch@suse.de
- libdrm 2.4.1
  * New libdrm release to fix the symbol name collision between
    Mesa 7.2 and libdrm_intel.  Also includes a fix for deadlock
    in non-GEM 2D, and support for aperture size checking in GEM.
  * Changes since commit a59ea02
  - intel: Rename dri_ and intel_ symbols to drm_intel_.
  - intel: Add dri_bufmgr_check_aperture support for bufmgr_gem.
  - nv50: symlink nv50_grctx.h to linux-core...
  - nv50: move context-related tables a separate header file
  - drm: missing init_mm symbol, compatibility fix
  - i915: Since FreeBSD doesn't have gem support yet, don't
    advertise it.
  - radeon: fix error in busmaster enable logic
  - radeon: fix some fallout from the busmaster disable cleanup
  - drm/i915: fix ioremap of a user address for non-root
    (CVE-2008-3831)
  - intel: Also total child_size of the target_bos. Partial fix
    [#17964].
  - [FreeBSD] We should use dev2unit() rather than minor()
  - [FreeBSD] This check isn't correct and causes at least mga
    to lockup.
* Tue Oct 21 2008 sndirsch@suse.de
- update to git commit a59ea02 (=2.4.1, Intel-2008-Q3-RC5)
  * avoid deadlock in intel_bufmgr_fake.
  * ioctl is not defined to return -errno. Don't count on ioctl
    returning -errno; use errno directly.
* Sun Oct 19 2008 sndirsch@suse.de
- libdrm 2.4.0 finally available
* Thu Oct  9 2008 sndirsch@suse.de
- updated to git commit ce40261, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC3)
* Fri Sep 26 2008 sndirsch@suse.de
- updated to git commit 2db8e0c, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC2)
* Wed Sep 24 2008 sndirsch@suse.de
- updated to git commit 973c634, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC1)
* Sun Aug 17 2008 sndirsch@suse.de
- updated to 2.4.0 prerelease (git commit a5381ca)
* Fri Jul  4 2008 sndirsch@suse.de
- updated to release 2.3.1
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun warning
- libdrm.la had an empty dependency_libs, removed.
* Sat Dec  2 2006 sndirsch@suse.de
- updated to 2.3.0 (required by X.Org (Server) 7.2 RC3)
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
* Wed Jun 28 2006 sndirsch@suse.de
- updated to 2.0.2
  * various bugfixes in libdrm
* Wed Jun 21 2006 sndirsch@suse.de
- updated to current CVS (2006-06-21)
* Sat Apr 15 2006 sndirsch@suse.de
- updated to 2.0.1
  * various bugfixes in libdrm
* Sat Feb  4 2006 aj@suse.de
- xorg-x11-devel is not needed for build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 mls@suse.de
- Require main package in devel subpackage
* Wed Nov 30 2005 sndirsch@suse.de
- update to 2.0 branch (2005-11-30)
* Tue Nov  1 2005 sndirsch@suse.de
- updated to 1.0.5 (version Bump for new via header)
* Sat Oct 29 2005 sndirsch@suse.de
- call ldconfig in %%post
* Tue Oct 25 2005 sndirsch@suse.de
- updated to CVS 051025 (required for Mesa 6.4)
* Tue Oct  4 2005 sndirsch@suse.de
- added libdrm.so to filelist
* Sun Oct  2 2005 sndirsch@suse.de
- created package
